#built-in
from pathlib import Path

#pip-install

#our package
from ..calculator import Calculator

class FileCalculator(Calculator):
    def sum_file(self, path):
        if path is None:
            path = Path(__file__).parent / "nums.csv"
        raise NotImplementedError



class Calculator:
    def __init__(self):
        print("I'm in calculator!")
    def add(self, a, b):
        return a + b
    def subtract(self, a, b):
        return a - b
    def multiple(self, a, b):
        return a * b
    def divide(self, a, b):
        return a / b
